import "./tasks/TNseq.wdl" as TNseq
import "./tasks/TNscope.wdl" as TNscope

workflow {{ project_name }} {
    
    String sample_id
    File tumor_bam
    File tumor_bai
    File tumor_table
    File normal_bam
    File normal_bai
    File normal_table

    String SENTIEON_INSTALL_DIR
    String SENTIEON_LICENSE
    String sentieon_docker
    String varscan_docker
    String annovar_docker
    String maftools_docker
    
    File ref_dir
    String fasta
    File dbmills_dir
    String db_mills
    File dbsnp_dir
    String dbsnp
    File germline_resource
    
    File? regions
    Int? interval_padding

    File database
    String disk_size
    String cluster_config

    File? tnseq_pon
    File? tnscope_pon
    File? cosmic_dir
    String? cosmic_vcf

    Boolean germline
    Boolean tnseq
    Boolean tnscope
    Boolean varscan

    if (tnseq) {
        call TNseq.TNseq as TNseq {
            input:
            SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
            SENTIEON_LICENSE=SENTIEON_LICENSE,
            sample=sample_id,
            normal_recaled_bam=normal_bam,
            normal_recaled_bam_index=normal_bai,
            normal_recal_table=normal_table,
            tumor_recaled_bam=tumor_bam,
            tumor_recaled_bam_index=tumor_bai,
            tumor_recal_table=tumor_table,
            normal_name=sample_id + "_normal",
            tumor_name=sample_id + "_tumor",
            fasta=fasta,
            ref_dir=ref_dir,
            regions=regions,
            interval_padding=interval_padding,
            germline_resource=germline_resource,
            pon_vcf=tnseq_pon,
            docker=sentieon_docker,
            cluster_config=cluster_config,
            disk_size=disk_size
        }
    }

    if (tnscope) {
        call TNscope.TNscope as TNscope {
            input:
            SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
            SENTIEON_LICENSE=SENTIEON_LICENSE,
            sample=sample_id,
            normal_recaled_bam=normal_bam,
            normal_recaled_bam_index=normal_bai,
            normal_recal_table=normal_table,
            tumor_recaled_bam=tumor_bam,
            tumor_recaled_bam_index=tumor_bai,
            tumor_recal_table=tumor_table,
            normal_name=sample_id + "_normal",
            tumor_name=sample_id + "_tumor",
            fasta=fasta,
            ref_dir=ref_dir,
            regions=regions,
            interval_padding=interval_padding,
            dbsnp=dbsnp,
            dbsnp_dir=dbsnp_dir,
            pon_vcf=tnscope_pon,
            docker=sentieon_docker,
            cluster_config=cluster_config,
            disk_size=disk_size
        }
    }
}